diff --git a/Content.Server/Advertise/EntitySystems/AdvertiseSystem.cs b/Content.Server/Advertise/EntitySystems/AdvertiseSystem.cs
index 28fa01628f..7f2e128183 100644
--- a/Content.Server/Advertise/EntitySystems/AdvertiseSystem.cs
+++ b/Content.Server/Advertise/EntitySystems/AdvertiseSystem.cs
@@ -62,7 +62,7 @@ public sealed class AdvertiseSystem : EntitySystem
return;
if (_prototypeManager.TryIndex(advert.Pack, out var advertisements))
- _chat.TrySendInGameICMessage(uid, Loc.GetString(_random.Pick(advertisements.Messages)), InGameICChatType.Speak, hideChat: true);
+ _chat.TrySendInGameICMessage(uid, Loc.GetString(_random.Pick(advertisements.Values)), InGameICChatType.Speak, hideChat: true);
}
public override void Update(float frameTime)
diff --git a/Content.Server/Advertise/EntitySystems/SpeakOnUIClosedSystem.cs b/Content.Server/Advertise/EntitySystems/SpeakOnUIClosedSystem.cs
index 232b4b7eda..a0a709e5fa 100644
--- a/Content.Server/Advertise/EntitySystems/SpeakOnUIClosedSystem.cs
+++ b/Content.Server/Advertise/EntitySystems/SpeakOnUIClosedSystem.cs
@@ -1,7 +1,6 @@
using Content.Server.Advertise.Components;
using Content.Server.Chat.Systems;
-using Content.Server.UserInterface;
-using Content.Shared.Advertise;
+using Content.Shared.Dataset;
using Robust.Shared.Prototypes;
using Robust.Shared.Random;
using ActivatableUIComponent = Content.Shared.UserInterface.ActivatableUIComponent;
@@ -39,10 +38,10 @@ public sealed partial class SpeakOnUIClosedSystem : EntitySystem
if (!entity.Comp.Enabled)
return false;
- if (!_prototypeManager.TryIndex(entity.Comp.Pack, out MessagePackPrototype? messagePack))
+ if (!_prototypeManager.TryIndex(entity.Comp.Pack, out var messagePack))
return false;
- var message = Loc.GetString(_random.Pick(messagePack.Messages), ("name", Name(entity)));
+ var message = Loc.GetString(_random.Pick(messagePack.Values), ("name", Name(entity)));
_chat.TrySendInGameICMessage(entity, message, InGameICChatType.Speak, true);
entity.Comp.Flag = false;
return true;
diff --git a/Content.Shared/Advertise/MessagePackPrototype.cs b/Content.Shared/Advertise/MessagePackPrototype.cs
deleted file mode 100644
index f7495d7e46..0000000000
--- a/Content.Shared/Advertise/MessagePackPrototype.cs
+++ /dev/null
@@ -1,14 +0,0 @@
-using Robust.Shared.Prototypes;
-
-namespace Content.Shared.Advertise;
-
-[Serializable, Prototype("messagePack")]
-public sealed partial class MessagePackPrototype : IPrototype
-{
- [ViewVariables]
- [IdDataField]
- public string ID { get; private set; } = default!;
-
- [DataField]
- public List Messages { get; private set; } = [];
-}
diff --git a/Resources/Locale/en-US/vending-machines/vending-machine.ftl b/Resources/Locale/en-US/vending-machines/vending-machine.ftl
index 637a9c7568..cb1dd3502f 100644
--- a/Resources/Locale/en-US/vending-machines/vending-machine.ftl
+++ b/Resources/Locale/en-US/vending-machines/vending-machine.ftl
@@ -1,3 +1,3 @@
-vending-machine-thanks = Thanks for using { $name }!
+vending-machine-thanks-1 = Thanks for using { $name }!
vending-machine-flavor-left = Request refills at cargo
vending-machine-flavor-right = v1.1
diff --git a/Resources/Prototypes/Catalog/Arcade/Advertisements/blockgame.yml b/Resources/Prototypes/Catalog/Arcade/Advertisements/blockgame.yml
deleted file mode 100644
index 7fb0367295..0000000000
--- a/Resources/Prototypes/Catalog/Arcade/Advertisements/blockgame.yml
+++ /dev/null
@@ -1,16 +0,0 @@
-- type: messagePack
- id: BlockGameAds
- messages:
- - advertisement-block-game-1
- - advertisement-block-game-2
- - advertisement-block-game-3
- - advertisement-block-game-4
- - advertisement-block-game-5
- - advertisement-block-game-6
- - advertisement-block-game-7
- - advertisement-block-game-8
- - advertisement-block-game-9
- - advertisement-block-game-10
- - advertisement-block-game-11
- - advertisement-block-game-12
- - advertisement-block-game-13
diff --git a/Resources/Prototypes/Catalog/Arcade/Advertisements/spacevillain.yml b/Resources/Prototypes/Catalog/Arcade/Advertisements/spacevillain.yml
deleted file mode 100644
index 7c94ab94f6..0000000000
--- a/Resources/Prototypes/Catalog/Arcade/Advertisements/spacevillain.yml
+++ /dev/null
@@ -1,18 +0,0 @@
-- type: messagePack
- id: SpaceVillainAds
- messages:
- - advertisement-space-villain-1
- - advertisement-space-villain-2
- - advertisement-space-villain-3
- - advertisement-space-villain-4
- - advertisement-space-villain-5
- - advertisement-space-villain-6
- - advertisement-space-villain-7
- - advertisement-space-villain-8
- - advertisement-space-villain-9
- - advertisement-space-villain-10
- - advertisement-space-villain-11
- - advertisement-space-villain-12
- - advertisement-space-villain-13
- - advertisement-space-villain-14
- - advertisement-space-villain-15
diff --git a/Resources/Prototypes/Catalog/Arcade/Goodbyes/blockgame.yml b/Resources/Prototypes/Catalog/Arcade/Goodbyes/blockgame.yml
deleted file mode 100644
index 460e8d13bf..0000000000
--- a/Resources/Prototypes/Catalog/Arcade/Goodbyes/blockgame.yml
+++ /dev/null
@@ -1,15 +0,0 @@
-- type: messagePack
- id: BlockGameGoodbyes
- messages:
- - thankyou-block-game-1
- - thankyou-block-game-2
- - thankyou-block-game-3
- - thankyou-block-game-4
- - thankyou-block-game-5
- - thankyou-block-game-6
- - thankyou-block-game-7
- - thankyou-block-game-8
- - thankyou-block-game-9
- - thankyou-block-game-10
- - thankyou-block-game-11
- - thankyou-block-game-12
diff --git a/Resources/Prototypes/Catalog/Arcade/Goodbyes/spacevillain.yml b/Resources/Prototypes/Catalog/Arcade/Goodbyes/spacevillain.yml
deleted file mode 100644
index 09016afec3..0000000000
--- a/Resources/Prototypes/Catalog/Arcade/Goodbyes/spacevillain.yml
+++ /dev/null
@@ -1,15 +0,0 @@
-- type: messagePack
- id: SpaceVillainGoodbyes
- messages:
- - thankyou-space-villain-1
- - thankyou-space-villain-2
- - thankyou-space-villain-3
- - thankyou-space-villain-4
- - thankyou-space-villain-5
- - thankyou-space-villain-6
- - thankyou-space-villain-7
- - thankyou-space-villain-8
- - thankyou-space-villain-9
- - thankyou-space-villain-10
- - thankyou-space-villain-11
- - thankyou-space-villain-12
diff --git a/Resources/Prototypes/Catalog/Arcade/advertisements.yml b/Resources/Prototypes/Catalog/Arcade/advertisements.yml
new file mode 100644
index 0000000000..47ecfb60b8
--- /dev/null
+++ b/Resources/Prototypes/Catalog/Arcade/advertisements.yml
@@ -0,0 +1,11 @@
+- type: localizedDataset
+ id: BlockGameAds
+ values:
+ prefix: advertisement-block-game-
+ count: 13
+
+- type: localizedDataset
+ id: SpaceVillainAds
+ values:
+ prefix: advertisement-space-villain-
+ count: 15
diff --git a/Resources/Prototypes/Catalog/Arcade/goodbyes.yml b/Resources/Prototypes/Catalog/Arcade/goodbyes.yml
new file mode 100644
index 0000000000..48b45eb40e
--- /dev/null
+++ b/Resources/Prototypes/Catalog/Arcade/goodbyes.yml
@@ -0,0 +1,11 @@
+- type: localizedDataset
+ id: BlockGameGoodbyes
+ values:
+ prefix: thankyou-block-game-
+ count: 12
+
+- type: localizedDataset
+ id: SpaceVillainGoodbyes
+ values:
+ prefix: thankyou-space-villain-
+ count: 12
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/ammo.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/ammo.yml
deleted file mode 100644
index 7e089a2825..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/ammo.yml
+++ /dev/null
@@ -1,13 +0,0 @@
-- type: messagePack
- id: AmmoVendAds
- messages:
- - advertisement-ammo-1
- - advertisement-ammo-2
- - advertisement-ammo-3
- - advertisement-ammo-4
- - advertisement-ammo-5
- - advertisement-ammo-6
- - advertisement-ammo-7
- - advertisement-ammo-8
- - advertisement-ammo-9
- - advertisement-ammo-10
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/atmosdrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/atmosdrobe.yml
deleted file mode 100644
index 7946c06310..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/atmosdrobe.yml
+++ /dev/null
@@ -1,6 +0,0 @@
-- type: messagePack
- id: AtmosDrobeAds
- messages:
- - advertisement-atmosdrobe-1
- - advertisement-atmosdrobe-2
- - advertisement-atmosdrobe-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/bardrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/bardrobe.yml
deleted file mode 100644
index 0a21acf2cb..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/bardrobe.yml
+++ /dev/null
@@ -1,5 +0,0 @@
-- type: messagePack
- id: BarDrobeAds
- messages:
- - advertisement-bardrobe-1
- - advertisement-bardrobe-2
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/boozeomat.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/boozeomat.yml
deleted file mode 100644
index e6bcbbcb9c..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/boozeomat.yml
+++ /dev/null
@@ -1,22 +0,0 @@
-- type: messagePack
- id: BoozeOMatAds
- messages:
- - advertisement-boozeomat-1
- - advertisement-boozeomat-2
- - advertisement-boozeomat-3
- - advertisement-boozeomat-4
- - advertisement-boozeomat-5
- - advertisement-boozeomat-6
- - advertisement-boozeomat-7
- - advertisement-boozeomat-8
- - advertisement-boozeomat-9
- - advertisement-boozeomat-10
- - advertisement-boozeomat-11
- - advertisement-boozeomat-12
- - advertisement-boozeomat-13
- - advertisement-boozeomat-14
- - advertisement-boozeomat-15
- - advertisement-boozeomat-16
- - advertisement-boozeomat-17
- - advertisement-boozeomat-18
- - advertisement-boozeomat-19
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/cargodrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/cargodrobe.yml
deleted file mode 100644
index f2cd38f737..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/cargodrobe.yml
+++ /dev/null
@@ -1,6 +0,0 @@
-- type: messagePack
- id: CargoDrobeAds
- messages:
- - advertisement-cargodrobe-1
- - advertisement-cargodrobe-2
- - advertisement-cargodrobe-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/chang.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/chang.yml
deleted file mode 100644
index 911d467e7d..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/chang.yml
+++ /dev/null
@@ -1,8 +0,0 @@
-- type: messagePack
- id: ChangAds
- messages:
- - advertisement-chang-1
- - advertisement-chang-2
- - advertisement-chang-3
- - advertisement-chang-4
- - advertisement-chang-5
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/chefdrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/chefdrobe.yml
deleted file mode 100644
index c71d8225e0..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/chefdrobe.yml
+++ /dev/null
@@ -1,6 +0,0 @@
-- type: messagePack
- id: ChefDrobeAds
- messages:
- - advertisement-chefdrobe-1
- - advertisement-chefdrobe-2
- - advertisement-chefdrobe-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/chefvend.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/chefvend.yml
deleted file mode 100644
index d52fcf9894..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/chefvend.yml
+++ /dev/null
@@ -1,12 +0,0 @@
-- type: messagePack
- id: ChefvendAds
- messages:
- - advertisement-chefvend-1
- - advertisement-chefvend-2
- - advertisement-chefvend-3
- - advertisement-chefvend-4
- - advertisement-chefvend-5
- - advertisement-chefvend-6
- - advertisement-chefvend-7
- - advertisement-chefvend-8
- - advertisement-chefvend-9
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/chemdrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/chemdrobe.yml
deleted file mode 100644
index 69a37de184..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/chemdrobe.yml
+++ /dev/null
@@ -1,6 +0,0 @@
-- type: messagePack
- id: ChemDrobeAds
- messages:
- - advertisement-chemdrobe-1
- - advertisement-chemdrobe-2
- - advertisement-chemdrobe-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/cigs.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/cigs.yml
deleted file mode 100644
index db3d492c45..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/cigs.yml
+++ /dev/null
@@ -1,15 +0,0 @@
-- type: messagePack
- id: CigaretteMachineAds
- messages:
- - advertisement-cigs-1
- - advertisement-cigs-2
- - advertisement-cigs-3
- - advertisement-cigs-4
- - advertisement-cigs-5
- - advertisement-cigs-6
- - advertisement-cigs-7
- - advertisement-cigs-8
- - advertisement-cigs-9
- - advertisement-cigs-10
- - advertisement-cigs-11
- - advertisement-cigs-12
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/clothesmate.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/clothesmate.yml
deleted file mode 100644
index dc109f8eb9..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/clothesmate.yml
+++ /dev/null
@@ -1,10 +0,0 @@
-- type: messagePack
- id: ClothesMateAds
- messages:
- - advertisement-clothes-1
- - advertisement-clothes-2
- - advertisement-clothes-3
- - advertisement-clothes-4
- - advertisement-clothes-5
- - advertisement-clothes-6
- - advertisement-clothes-7
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/coffee.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/coffee.yml
deleted file mode 100644
index 4781768cf0..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/coffee.yml
+++ /dev/null
@@ -1,17 +0,0 @@
-- type: messagePack
- id: HotDrinksMachineAds
- messages:
- - advertisement-coffee-1
- - advertisement-coffee-2
- - advertisement-coffee-3
- - advertisement-coffee-4
- - advertisement-coffee-5
- - advertisement-coffee-6
- - advertisement-coffee-7
- - advertisement-coffee-8
- - advertisement-coffee-9
- - advertisement-coffee-10
- - advertisement-coffee-11
- - advertisement-coffee-12
- - advertisement-coffee-13
- - advertisement-coffee-14
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/cola.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/cola.yml
deleted file mode 100644
index d12d7eb92f..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/cola.yml
+++ /dev/null
@@ -1,11 +0,0 @@
-- type: messagePack
- id: RobustSoftdrinksAds
- messages:
- - advertisement-cola-1
- - advertisement-cola-2
- - advertisement-cola-3
- - advertisement-cola-4
- - advertisement-cola-5
- - advertisement-cola-6
- - advertisement-cola-7
- - advertisement-cola-8
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/condiments.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/condiments.yml
deleted file mode 100644
index d1d07df0c4..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/condiments.yml
+++ /dev/null
@@ -1,9 +0,0 @@
-- type: messagePack
- id: CondimentVendAds
- messages:
- - advertisement-condiment-1
- - advertisement-condiment-2
- - advertisement-condiment-3
- - advertisement-condiment-4
- - advertisement-condiment-5
- - advertisement-condiment-6
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/curadrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/curadrobe.yml
deleted file mode 100644
index 47523c6e93..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/curadrobe.yml
+++ /dev/null
@@ -1,6 +0,0 @@
-- type: messagePack
- id: CuraDrobeAds
- messages:
- - advertisement-curadrobe-1
- - advertisement-curadrobe-2
- - advertisement-curadrobe-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/detdrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/detdrobe.yml
deleted file mode 100644
index 50024ce3d9..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/detdrobe.yml
+++ /dev/null
@@ -1,6 +0,0 @@
-- type: messagePack
- id: DetDrobeAds
- messages:
- - advertisement-detdrobe-1
- - advertisement-detdrobe-2
- - advertisement-detdrobe-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/dinnerware.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/dinnerware.yml
deleted file mode 100644
index ac31dc075b..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/dinnerware.yml
+++ /dev/null
@@ -1,13 +0,0 @@
-- type: messagePack
- id: DinnerwareAds
- messages:
- - advertisement-dinnerware-1
- - advertisement-dinnerware-2
- - advertisement-dinnerware-3
- - advertisement-dinnerware-4
- - advertisement-dinnerware-5
- - advertisement-dinnerware-6
- - advertisement-dinnerware-7
- - advertisement-dinnerware-8
- - advertisement-dinnerware-9
- - advertisement-dinnerware-10
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/discount.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/discount.yml
deleted file mode 100644
index dce8646a60..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/discount.yml
+++ /dev/null
@@ -1,12 +0,0 @@
-- type: messagePack
- id: DiscountDansAds
- messages:
- - advertisement-discount-1
- - advertisement-discount-2
- - advertisement-discount-3
- - advertisement-discount-4
- - advertisement-discount-5
- - advertisement-discount-6
- - advertisement-discount-7
- - advertisement-discount-8
- - advertisement-discount-9
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/donut.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/donut.yml
deleted file mode 100644
index 73766aa749..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/donut.yml
+++ /dev/null
@@ -1,8 +0,0 @@
-- type: messagePack
- id: DonutAds
- messages:
- - advertisement-donut-1
- - advertisement-donut-2
- - advertisement-donut-3
- - advertisement-donut-4
- - advertisement-donut-5
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/engidrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/engidrobe.yml
deleted file mode 100644
index ec92fbe4de..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/engidrobe.yml
+++ /dev/null
@@ -1,8 +0,0 @@
-- type: messagePack
- id: EngiDrobeAds
- messages:
- - advertisement-engidrobe-1
- - advertisement-engidrobe-2
- - advertisement-engidrobe-3
- - advertisement-engidrobe-4
- - advertisement-engidrobe-5
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/fatextractor.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/fatextractor.yml
deleted file mode 100644
index 7619ea1856..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/fatextractor.yml
+++ /dev/null
@@ -1,9 +0,0 @@
-- type: messagePack
- id: FatExtractorFacts
- messages:
- - fat-extractor-fact-1
- - fat-extractor-fact-2
- - fat-extractor-fact-3
- - fat-extractor-fact-4
- - fat-extractor-fact-5
- - fat-extractor-fact-6
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/games.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/games.yml
deleted file mode 100644
index 1348635e1f..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/games.yml
+++ /dev/null
@@ -1,13 +0,0 @@
-- type: messagePack
- id: GoodCleanFunAds
- messages:
- - advertisement-goodcleanfun-1
- - advertisement-goodcleanfun-2
- - advertisement-goodcleanfun-3
- - advertisement-goodcleanfun-4
- - advertisement-goodcleanfun-5
- - advertisement-goodcleanfun-6
- - advertisement-goodcleanfun-7
- - advertisement-goodcleanfun-8
- - advertisement-goodcleanfun-9
- - advertisement-goodcleanfun-10
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/genedrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/genedrobe.yml
deleted file mode 100644
index 722388055b..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/genedrobe.yml
+++ /dev/null
@@ -1,5 +0,0 @@
-- type: messagePack
- id: GeneDrobeAds
- messages:
- - advertisement-genedrobe-1
- - advertisement-genedrobe-2
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/happyhonk.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/happyhonk.yml
deleted file mode 100644
index e145ebcdac..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/happyhonk.yml
+++ /dev/null
@@ -1,13 +0,0 @@
-- type: messagePack
- id: HappyHonkAds
- messages:
- - advertisement-happyhonk-1
- - advertisement-happyhonk-2
- - advertisement-happyhonk-3
- - advertisement-happyhonk-4
- - advertisement-happyhonk-5
- - advertisement-happyhonk-6
- - advertisement-happyhonk-7
- - advertisement-happyhonk-8
- - advertisement-happyhonk-9
- - advertisement-happyhonk-10
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/hydrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/hydrobe.yml
deleted file mode 100644
index 5999c496f5..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/hydrobe.yml
+++ /dev/null
@@ -1,7 +0,0 @@
-- type: messagePack
- id: HyDrobeAds
- messages:
- - advertisement-hydrobe-1
- - advertisement-hydrobe-2
- - advertisement-hydrobe-3
- - advertisement-hydrobe-4
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/janidrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/janidrobe.yml
deleted file mode 100644
index 8310136bf8..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/janidrobe.yml
+++ /dev/null
@@ -1,6 +0,0 @@
-- type: messagePack
- id: JaniDrobeAds
- messages:
- - advertisement-janidrobe-1
- - advertisement-janidrobe-2
- - advertisement-janidrobe-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/lawdrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/lawdrobe.yml
deleted file mode 100644
index a948413abd..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/lawdrobe.yml
+++ /dev/null
@@ -1,11 +0,0 @@
-- type: messagePack
- id: LawDrobeAds
- messages:
- - advertisement-lawdrobe-1
- - advertisement-lawdrobe-2
- - advertisement-lawdrobe-3
- - advertisement-lawdrobe-4
- - advertisement-lawdrobe-5
- - advertisement-lawdrobe-6
- - advertisement-lawdrobe-7
- - advertisement-lawdrobe-8
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/magivend.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/magivend.yml
deleted file mode 100644
index 896a3853e7..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/magivend.yml
+++ /dev/null
@@ -1,14 +0,0 @@
-- type: messagePack
- id: MagiVendAds
- messages:
- - advertisement-magivend-1
- - advertisement-magivend-2
- - advertisement-magivend-3
- - advertisement-magivend-4
- - advertisement-magivend-5
- - advertisement-magivend-6
- - advertisement-magivend-7
- - advertisement-magivend-8
- - advertisement-magivend-9
- - advertisement-magivend-10
- - advertisement-magivend-11
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/medidrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/medidrobe.yml
deleted file mode 100644
index b7b055231b..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/medidrobe.yml
+++ /dev/null
@@ -1,6 +0,0 @@
-- type: messagePack
- id: MediDrobeAds
- messages:
- - advertisement-medidrobe-1
- - advertisement-medidrobe-2
- - advertisement-medidrobe-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/megaseed.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/megaseed.yml
deleted file mode 100644
index b6e6ae098e..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/megaseed.yml
+++ /dev/null
@@ -1,9 +0,0 @@
-- type: messagePack
- id: MegaSeedAds
- messages:
- - advertisement-megaseed-1
- - advertisement-megaseed-2
- - advertisement-megaseed-3
- - advertisement-megaseed-4
- - advertisement-megaseed-5
- - advertisement-megaseed-6
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/nanomed.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/nanomed.yml
deleted file mode 100644
index a79a4c8a6c..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/nanomed.yml
+++ /dev/null
@@ -1,12 +0,0 @@
-- type: messagePack
- id: NanoMedAds
- messages:
- - advertisement-nanomed-1
- - advertisement-nanomed-2
- - advertisement-nanomed-3
- - advertisement-nanomed-4
- - advertisement-nanomed-5
- - advertisement-nanomed-6
- - advertisement-nanomed-7
- - advertisement-nanomed-8
- - advertisement-nanomed-9
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/nutrimax.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/nutrimax.yml
deleted file mode 100644
index a3ade34960..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/nutrimax.yml
+++ /dev/null
@@ -1,10 +0,0 @@
-- type: messagePack
- id: NutriMaxAds
- messages:
- - advertisement-nutrimax-1
- - advertisement-nutrimax-2
- - advertisement-nutrimax-3
- - advertisement-nutrimax-4
- - advertisement-nutrimax-5
- - advertisement-nutrimax-6
- - advertisement-nutrimax-7
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/robodrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/robodrobe.yml
deleted file mode 100644
index 82ece7d763..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/robodrobe.yml
+++ /dev/null
@@ -1,7 +0,0 @@
-- type: messagePack
- id: RoboDrobeAds
- messages:
- - advertisement-robodrobe-1
- - advertisement-robodrobe-2
- - advertisement-robodrobe-3
- - advertisement-robodrobe-4
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/scidrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/scidrobe.yml
deleted file mode 100644
index f8b125073b..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/scidrobe.yml
+++ /dev/null
@@ -1,6 +0,0 @@
-- type: messagePack
- id: SciDrobeAds
- messages:
- - advertisement-scidrobe-1
- - advertisement-scidrobe-2
- - advertisement-scidrobe-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/secdrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/secdrobe.yml
deleted file mode 100644
index 99c2c402de..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/secdrobe.yml
+++ /dev/null
@@ -1,8 +0,0 @@
-- type: messagePack
- id: SecDrobeAds
- messages:
- - advertisement-secdrobe-1
- - advertisement-secdrobe-2
- - advertisement-secdrobe-3
- - advertisement-secdrobe-4
- - advertisement-secdrobe-5
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/sectech.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/sectech.yml
deleted file mode 100644
index 0b32ed166d..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/sectech.yml
+++ /dev/null
@@ -1,8 +0,0 @@
-- type: messagePack
- id: SecTechAds
- messages:
- - advertisement-sectech-1
- - advertisement-sectech-2
- - advertisement-sectech-3
- - advertisement-sectech-4
- - advertisement-sectech-5
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/smartfridge.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/smartfridge.yml
deleted file mode 100644
index d92a95f70f..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/smartfridge.yml
+++ /dev/null
@@ -1,11 +0,0 @@
-- type: messagePack
- id: SmartFridgeAds
- messages:
- - advertisement-smartfridge-1
- - advertisement-smartfridge-2
- - advertisement-smartfridge-3
- - advertisement-smartfridge-4
- - advertisement-smartfridge-5
- - advertisement-smartfridge-6
- - advertisement-smartfridge-7
- - advertisement-smartfridge-8
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/snack.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/snack.yml
deleted file mode 100644
index 3d9b93f9c2..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/snack.yml
+++ /dev/null
@@ -1,18 +0,0 @@
-- type: messagePack
- id: GetmoreChocolateCorpAds
- messages:
- - advertisement-snack-1
- - advertisement-snack-2
- - advertisement-snack-3
- - advertisement-snack-4
- - advertisement-snack-5
- - advertisement-snack-6
- - advertisement-snack-7
- - advertisement-snack-8
- - advertisement-snack-9
- - advertisement-snack-10
- - advertisement-snack-11
- - advertisement-snack-12
- - advertisement-snack-13
- - advertisement-snack-14
- - advertisement-snack-15
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/sovietsoda.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/sovietsoda.yml
deleted file mode 100644
index 630de1e615..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/sovietsoda.yml
+++ /dev/null
@@ -1,9 +0,0 @@
-- type: messagePack
- id: BodaAds
- messages:
- - advertisement-sovietsoda-1
- - advertisement-sovietsoda-2
- - advertisement-sovietsoda-3
- - advertisement-sovietsoda-4
- - advertisement-sovietsoda-5
- - advertisement-sovietsoda-6
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/syndiedrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/syndiedrobe.yml
deleted file mode 100644
index dc89d04aa0..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/syndiedrobe.yml
+++ /dev/null
@@ -1,34 +0,0 @@
-- type: messagePack
- id: SyndieDrobeAds
- messages:
- - advertisement-syndiedrobe-1
- - advertisement-syndiedrobe-2
- - advertisement-syndiedrobe-3
- - advertisement-syndiedrobe-4
- - advertisement-syndiedrobe-5
- - advertisement-syndiedrobe-6
- - advertisement-syndiedrobe-7
- - advertisement-syndiedrobe-8
- - advertisement-syndiedrobe-9
- - advertisement-syndiedrobe-10
- - advertisement-syndiedrobe-11
- - advertisement-syndiedrobe-12
- - advertisement-syndiedrobe-13
- - advertisement-syndiedrobe-14
- - advertisement-syndiedrobe-15
- - advertisement-syndiedrobe-16
- - advertisement-syndiedrobe-17
- - advertisement-syndiedrobe-18
- - advertisement-syndiedrobe-19
- - advertisement-syndiedrobe-20
- - advertisement-syndiedrobe-21
- - advertisement-syndiedrobe-22
- - advertisement-syndiedrobe-23
- - advertisement-syndiedrobe-24
- - advertisement-syndiedrobe-25
- - advertisement-syndiedrobe-26
- - advertisement-syndiedrobe-27
- - advertisement-syndiedrobe-28
- - advertisement-syndiedrobe-29
- - advertisement-syndiedrobe-30
- - advertisement-syndiedrobe-31
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/theater.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/theater.yml
deleted file mode 100644
index 8b06cdb517..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/theater.yml
+++ /dev/null
@@ -1,9 +0,0 @@
-- type: messagePack
- id: AutoDrobeAds
- messages:
- - advertisement-theater-1
- - advertisement-theater-2
- - advertisement-theater-3
- - advertisement-theater-4
- - advertisement-theater-5
- - advertisement-theater-6
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/vendomat.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/vendomat.yml
deleted file mode 100644
index 31c0e0c241..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/vendomat.yml
+++ /dev/null
@@ -1,10 +0,0 @@
-- type: messagePack
- id: VendomatAds
- messages:
- - advertisement-vendomat-1
- - advertisement-vendomat-2
- - advertisement-vendomat-3
- - advertisement-vendomat-4
- - advertisement-vendomat-5
- - advertisement-vendomat-6
- - advertisement-vendomat-7
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/virodrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Advertisements/virodrobe.yml
deleted file mode 100644
index c48f9e7d2e..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Advertisements/virodrobe.yml
+++ /dev/null
@@ -1,6 +0,0 @@
-- type: messagePack
- id: ViroDrobeAds
- messages:
- - advertisement-virodrobe-1
- - advertisement-virodrobe-2
- - advertisement-virodrobe-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/boozeomat.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/boozeomat.yml
deleted file mode 100644
index e5c96887b9..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/boozeomat.yml
+++ /dev/null
@@ -1,7 +0,0 @@
-- type: messagePack
- id: BoozeOMatGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-boozeomat-1
- - thankyou-boozeomat-2
- - thankyou-boozeomat-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/chang.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/chang.yml
deleted file mode 100644
index a348d8fa9c..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/chang.yml
+++ /dev/null
@@ -1,6 +0,0 @@
-- type: messagePack
- id: ChangGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-chang-1
- - thankyou-chang-2
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/chefvend.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/chefvend.yml
deleted file mode 100644
index 93249586e1..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/chefvend.yml
+++ /dev/null
@@ -1,8 +0,0 @@
-- type: messagePack
- id: ChefvendGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-chefvend-1
- - thankyou-chefvend-2
- - thankyou-chefvend-3
- - thankyou-chefvend-4
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/cigs.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/cigs.yml
deleted file mode 100644
index 108a34a472..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/cigs.yml
+++ /dev/null
@@ -1,7 +0,0 @@
-- type: messagePack
- id: CigaretteMachineGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-cigs-1
- - thankyou-cigs-2
- - thankyou-cigs-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/coffee.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/coffee.yml
deleted file mode 100644
index 6f2aef01b8..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/coffee.yml
+++ /dev/null
@@ -1,8 +0,0 @@
-- type: messagePack
- id: HotDrinksMachineGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-coffee-1
- - thankyou-coffee-2
- - thankyou-coffee-3
- - thankyou-coffee-4
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/cola.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/cola.yml
deleted file mode 100644
index 76f00fddaf..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/cola.yml
+++ /dev/null
@@ -1,8 +0,0 @@
-- type: messagePack
- id: RobustSoftdrinksGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-cola-1
- - thankyou-cola-2
- - thankyou-cola-3
- - thankyou-cola-4
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/discount.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/discount.yml
deleted file mode 100644
index d3f7d89a93..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/discount.yml
+++ /dev/null
@@ -1,12 +0,0 @@
-- type: messagePack
- id: DiscountDansGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-discount-1
- - thankyou-discount-2
- - thankyou-discount-3
- - thankyou-discount-4
- - thankyou-discount-5
- - thankyou-discount-6
- - thankyou-discount-7
- - thankyou-discount-8
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/donut.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/donut.yml
deleted file mode 100644
index 3c28741e3b..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/donut.yml
+++ /dev/null
@@ -1,8 +0,0 @@
-- type: messagePack
- id: DonutGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-donut-1
- - thankyou-donut-2
- - thankyou-donut-3
- - thankyou-donut-4
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/games.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/games.yml
deleted file mode 100644
index 5d842619bb..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/games.yml
+++ /dev/null
@@ -1,8 +0,0 @@
-- type: messagePack
- id: GoodCleanFunGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-goodcleanfun-1
- - thankyou-goodcleanfun-2
- - thankyou-goodcleanfun-3
- - thankyou-goodcleanfun-4
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/generic.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/generic.yml
deleted file mode 100644
index 98a2d7d17a..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/generic.yml
+++ /dev/null
@@ -1,4 +0,0 @@
-- type: messagePack
- id: GenericVendGoodbyes
- messages:
- - vending-machine-thanks
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/happyhonk.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/happyhonk.yml
deleted file mode 100644
index 7859d55463..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/happyhonk.yml
+++ /dev/null
@@ -1,8 +0,0 @@
-- type: messagePack
- id: HappyHonkGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-happyhonk-1
- - thankyou-happyhonk-2
- - thankyou-happyhonk-3
- - thankyou-happyhonk-4
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/lawdrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/lawdrobe.yml
deleted file mode 100644
index 56678c1017..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/lawdrobe.yml
+++ /dev/null
@@ -1,8 +0,0 @@
-- type: messagePack
- id: LawDrobeGoodbyes
- messages:
- - thankyou-lawdrobe-1
- - thankyou-lawdrobe-2
- - thankyou-lawdrobe-3
- - thankyou-lawdrobe-4
- - thankyou-lawdrobe-5
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/nutrimax.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/nutrimax.yml
deleted file mode 100644
index 3568ae3031..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/nutrimax.yml
+++ /dev/null
@@ -1,6 +0,0 @@
-- type: messagePack
- id: NutriMaxGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-nutrimax-1
- - thankyou-nutrimax-2
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/sectech.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/sectech.yml
deleted file mode 100644
index 8909693473..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/sectech.yml
+++ /dev/null
@@ -1,7 +0,0 @@
-- type: messagePack
- id: SecTechGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-sectech-1
- - thankyou-sectech-2
- - thankyou-sectech-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/snack.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/snack.yml
deleted file mode 100644
index bd86e074c6..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/snack.yml
+++ /dev/null
@@ -1,10 +0,0 @@
-- type: messagePack
- id: GetmoreChocolateCorpGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-snack-1
- - thankyou-snack-2
- - thankyou-snack-3
- - thankyou-snack-4
- - thankyou-snack-5
- - thankyou-snack-6
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/sovietsoda.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/sovietsoda.yml
deleted file mode 100644
index 01ab25a7ad..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/sovietsoda.yml
+++ /dev/null
@@ -1,7 +0,0 @@
-- type: messagePack
- id: BodaGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-sovietsoda-1
- - thankyou-sovietsoda-2
- - thankyou-sovietsoda-3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/syndiedrobe.yml b/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/syndiedrobe.yml
deleted file mode 100644
index 1246eb3089..0000000000
--- a/Resources/Prototypes/Catalog/VendingMachines/Goodbyes/syndiedrobe.yml
+++ /dev/null
@@ -1,9 +0,0 @@
-- type: messagePack
- id: SyndieDrobeGoodbyes
- messages:
- - vending-machine-thanks
- - thankyou-syndiedrobe-1
- - thankyou-syndiedrobe-2
- - thankyou-syndiedrobe-3
- - thankyou-syndiedrobe-4
- - thankyou-syndiedrobe-5
diff --git a/Resources/Prototypes/Catalog/VendingMachines/advertisements.yml b/Resources/Prototypes/Catalog/VendingMachines/advertisements.yml
new file mode 100644
index 0000000000..6dbb60af6a
--- /dev/null
+++ b/Resources/Prototypes/Catalog/VendingMachines/advertisements.yml
@@ -0,0 +1,257 @@
+- type: localizedDataset
+ id: AmmoVendAds
+ values:
+ prefix: advertisement-ammo-
+ count: 10
+
+- type: localizedDataset
+ id: AtmosDrobeAds
+ values:
+ prefix: advertisement-atmosdrobe-
+ count: 3
+
+- type: localizedDataset
+ id: BarDrobeAds
+ values:
+ prefix: advertisement-bardrobe-
+ count: 2
+
+- type: localizedDataset
+ id: BoozeOMatAds
+ values:
+ prefix: advertisement-boozeomat-
+ count: 19
+
+- type: localizedDataset
+ id: CargoDrobeAds
+ values:
+ prefix: advertisement-cargodrobe-
+ count: 3
+
+- type: localizedDataset
+ id: ChangAds
+ values:
+ prefix: advertisement-chang-
+ count: 5
+
+- type: localizedDataset
+ id: ChefDrobeAds
+ values:
+ prefix: advertisement-chefdrobe-
+ count: 3
+
+- type: localizedDataset
+ id: ChefvendAds
+ values:
+ prefix: advertisement-chefvend-
+ count: 9
+
+- type: localizedDataset
+ id: ChemDrobeAds
+ values:
+ prefix: advertisement-chemdrobe-
+ count: 3
+
+- type: localizedDataset
+ id: CigaretteMachineAds
+ values:
+ prefix: advertisement-cigs-
+ count: 12
+
+- type: localizedDataset
+ id: ClothesMateAds
+ values:
+ prefix: advertisement-clothes-
+ count: 7
+
+- type: localizedDataset
+ id: HotDrinksMachineAds
+ values:
+ prefix: advertisement-coffee-
+ count: 14
+
+- type: localizedDataset
+ id: RobustSoftdrinksAds
+ values:
+ prefix: advertisement-cola-
+ count: 8
+
+- type: localizedDataset
+ id: CondimentVendAds
+ values:
+ prefix: advertisement-condiment-
+ count: 6
+
+- type: localizedDataset
+ id: CuraDrobeAds
+ values:
+ prefix: advertisement-curadrobe-
+ count: 3
+
+- type: localizedDataset
+ id: DetDrobeAds
+ values:
+ prefix: advertisement-detdrobe-
+ count: 3
+
+- type: localizedDataset
+ id: DinnerwareAds
+ values:
+ prefix: advertisement-dinnerware-
+ count: 10
+
+- type: localizedDataset
+ id: DiscountDansAds
+ values:
+ prefix: advertisement-discount-
+ count: 9
+
+- type: localizedDataset
+ id: DonutAds
+ values:
+ prefix: advertisement-donut-
+ count: 5
+
+- type: localizedDataset
+ id: EngiDrobeAds
+ values:
+ prefix: advertisement-engidrobe-
+ count: 5
+
+- type: localizedDataset
+ id: FatExtractorFacts
+ values:
+ prefix: fat-extractor-fact-
+ count: 6
+
+- type: localizedDataset
+ id: GoodCleanFunAds
+ values:
+ prefix: advertisement-goodcleanfun-
+ count: 10
+
+- type: localizedDataset
+ id: GeneDrobeAds
+ values:
+ prefix: advertisement-genedrobe-
+ count: 2
+
+- type: localizedDataset
+ id: HappyHonkAds
+ values:
+ prefix: advertisement-happyhonk-
+ count: 10
+
+- type: localizedDataset
+ id: HyDrobeAds
+ values:
+ prefix: advertisement-hydrobe-
+ count: 4
+
+- type: localizedDataset
+ id: JaniDrobeAds
+ values:
+ prefix: advertisement-janidrobe-
+ count: 3
+
+- type: localizedDataset
+ id: LawDrobeAds
+ values:
+ prefix: advertisement-lawdrobe-
+ count: 8
+
+- type: localizedDataset
+ id: MagiVendAds
+ values:
+ prefix: advertisement-magivend-
+ count: 11
+
+- type: localizedDataset
+ id: MediDrobeAds
+ values:
+ prefix: advertisement-medidrobe-
+ count: 3
+
+- type: localizedDataset
+ id: MegaSeedAds
+ values:
+ prefix: advertisement-megaseed-
+ count: 6
+
+- type: localizedDataset
+ id: NanoMedAds
+ values:
+ prefix: advertisement-nanomed-
+ count: 9
+
+- type: localizedDataset
+ id: NutriMaxAds
+ values:
+ prefix: advertisement-nutrimax-
+ count: 7
+
+- type: localizedDataset
+ id: RoboDrobeAds
+ values:
+ prefix: advertisement-robodrobe-
+ count: 4
+
+- type: localizedDataset
+ id: SciDrobeAds
+ values:
+ prefix: advertisement-scidrobe-
+ count: 3
+
+- type: localizedDataset
+ id: SecDrobeAds
+ values:
+ prefix: advertisement-secdrobe-
+ count: 5
+
+- type: localizedDataset
+ id: SecTechAds
+ values:
+ prefix: advertisement-sectech-
+ count: 5
+
+- type: localizedDataset
+ id: SmartFridgeAds
+ values:
+ prefix: advertisement-smartfridge-
+ count: 8
+
+- type: localizedDataset
+ id: GetmoreChocolateCorpAds
+ values:
+ prefix: advertisement-snack-
+ count: 15
+
+- type: localizedDataset
+ id: BodaAds
+ values:
+ prefix: advertisement-sovietsoda-
+ count: 6
+
+- type: localizedDataset
+ id: SyndieDrobeAds
+ values:
+ prefix: advertisement-syndiedrobe-
+ count: 31
+
+- type: localizedDataset
+ id: AutoDrobeAds
+ values:
+ prefix: advertisement-theater-
+ count: 6
+
+- type: localizedDataset
+ id: VendomatAds
+ values:
+ prefix: advertisement-vendomat-
+ count: 7
+
+- type: localizedDataset
+ id: ViroDrobeAds
+ values:
+ prefix: advertisement-virodrobe-
+ count: 3
diff --git a/Resources/Prototypes/Catalog/VendingMachines/goodbyes.yml b/Resources/Prototypes/Catalog/VendingMachines/goodbyes.yml
new file mode 100644
index 0000000000..5a3d91db11
--- /dev/null
+++ b/Resources/Prototypes/Catalog/VendingMachines/goodbyes.yml
@@ -0,0 +1,101 @@
+- type: localizedDataset
+ id: BoozeOMatGoodbyes
+ values:
+ prefix: thankyou-boozeomat-
+ count: 3
+
+- type: localizedDataset
+ id: ChangGoodbyes
+ values:
+ prefix: thankyou-chang-
+ count: 2
+
+- type: localizedDataset
+ id: ChefvendGoodbyes
+ values:
+ prefix: thankyou-chefvend-
+ count: 4
+
+- type: localizedDataset
+ id: CigaretteMachineGoodbyes
+ values:
+ prefix: thankyou-cigs-
+ count: 3
+
+- type: localizedDataset
+ id: HotDrinksMachineGoodbyes
+ values:
+ prefix: thankyou-coffee-
+ count: 4
+
+- type: localizedDataset
+ id: RobustSoftdrinksGoodbyes
+ values:
+ prefix: thankyou-cola-
+ count: 4
+
+- type: localizedDataset
+ id: DiscountDansGoodbyes
+ values:
+ prefix: thankyou-discount-
+ count: 8
+
+- type: localizedDataset
+ id: DonutGoodbyes
+ values:
+ prefix: thankyou-donut-
+ count: 4
+
+- type: localizedDataset
+ id: GoodCleanFunGoodbyes
+ values:
+ prefix: thankyou-goodcleanfun-
+ count: 4
+
+- type: localizedDataset
+ id: GenericVendGoodbyes
+ values:
+ prefix: vending-machine-thanks-
+ count: 1
+
+- type: localizedDataset
+ id: HappyHonkGoodbyes
+ values:
+ prefix: thankyou-happyhonk-
+ count: 4
+
+- type: localizedDataset
+ id: LawDrobeGoodbyes
+ values:
+ prefix: thankyou-lawdrobe-
+ count: 5
+
+- type: localizedDataset
+ id: NutriMaxGoodbyes
+ values:
+ prefix: thankyou-nutrimax-
+ count: 2
+
+- type: localizedDataset
+ id: SecTechGoodbyes
+ values:
+ prefix: thankyou-sectech-
+ count: 3
+
+- type: localizedDataset
+ id: GetmoreChocolateCorpGoodbyes
+ values:
+ prefix: thankyou-snack-
+ count: 6
+
+- type: localizedDataset
+ id: BodaGoodbyes
+ values:
+ prefix: thankyou-sovietsoda-
+ count: 3
+
+- type: localizedDataset
+ id: SyndieDrobeGoodbyes
+ values:
+ prefix: thankyou-syndiedrobe-
+ count: 5
diff --git a/Content.Server/Advertise/Components/AdvertiseComponent.cs b/Content.Server/Advertise/Components/AdvertiseComponent.cs
index 3d617e3a34..94650234bb 100644
--- a/Content.Server/Advertise/Components/AdvertiseComponent.cs
+++ b/Content.Server/Advertise/Components/AdvertiseComponent.cs
@@ -1,12 +1,12 @@
using Content.Server.Advertise.EntitySystems;
-using Content.Shared.Advertise;
+using Content.Shared.Dataset;
using Robust.Shared.Prototypes;
namespace Content.Server.Advertise.Components;
///
/// Makes this entity periodically advertise by speaking a randomly selected
/// message from a specified MessagePack into local chat.
///
[RegisterComponent, Access(typeof(AdvertiseSystem))]
public sealed partial class AdvertiseComponent : Component
@@ -33,10 +33,10 @@ public sealed partial class AdvertiseComponent : Component
public bool Prewarm = true;
///
/// The identifier for the advertisements pack prototype.
///
[DataField(required: true)]
- public ProtoId Pack { get; private set; }
+ public ProtoId Pack { get; private set; }
///
/// The next time an advertisement will be said.
@@ -1,12 +1,12 @@
///
/// Makes this entity periodically advertise by speaking a randomly selected
-/// message from a specified MessagePack into local chat.
+/// message from a specified dataset into local chat.
///
[RegisterComponent, Access(typeof(AdvertiseSystem))]
@@ -33,10 +33,10 @@ public sealed partial class AdvertiseComponent : Component
public bool Prewarm = true;
///
- /// The identifier for the advertisements pack prototype.
+ /// The identifier for the advertisements dataset prototype.
///
[DataField(required: true)]
diff --git a/Content.Server/Advertise/Components/SpeakOnUIClosedComponent.cs b/Content.Server/Advertise/Components/SpeakOnUIClosedComponent.cs
index 2a663b7f89..99d0080d7f 100644
--- a/Content.Server/Advertise/Components/SpeakOnUIClosedComponent.cs
+++ b/Content.Server/Advertise/Components/SpeakOnUIClosedComponent.cs
@@ -1,4 +1,4 @@
-using Content.Shared.Advertise;
+using Content.Shared.Dataset;
using Robust.Shared.Prototypes;
namespace Content.Server.Advertise.Components;
@@ -11,10 +11,10 @@ namespace Content.Server.Advertise.Components;
public sealed partial class SpeakOnUIClosedComponent : Component
{
///
/// The identifier for the message pack prototype containing messages to be spoken by this entity.
///
[DataField(required: true)]
- public ProtoId Pack { get; private set; }
+ public ProtoId Pack { get; private set; }
///
/// Is this component active? If false, no messages will be spoken.
@@ -11,10 +11,10 @@ namespace Content.Server.Advertise.Components;
{
///
- /// The identifier for the message pack prototype containing messages to be spoken by this entity.
+ /// The identifier for the dataset prototype containing messages to be spoken by this entity.
///
[DataField(required: true)]